All changelogs
==============

For version 0.4.x
-----------------

version 0.4.1
^^^^^^^^^^^^^

* Fix missing dependencies

version 0.4
^^^^^^^^^^^

* Enable class TIMEZONE definition
* Set order of extends
